logLik.srafit <-
function (object, ...) 
{
    stats4::logLik(object$model, ...)
}
